'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Dropdown = undefined;

var _babelHelperVueJsxMergeProps = require('babel-helper-vue-jsx-merge-props');

var _babelHelperVueJsxMergeProps2 = _interopRequireDefault(_babelHelperVueJsxMergeProps);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Dropdown = exports.Dropdown = {
  name: 'dropdown-component',
  functional: true,
  props: {
    options: { type: [Array], required: false },
    selectedOption: { type: [Object], required: false },
    placeholder: { type: [String], required: false },
    loadingText: { type: [String], required: false },
    disabled: { type: [Boolean], required: false },
    classes: { type: [String], required: false },
    label: { type: [String], required: false }
  },
  render: function render(h, context) {
    var _context$props = context.props,
        selectedOption = _context$props.selectedOption,
        placeholder = _context$props.placeholder,
        disabled = _context$props.disabled,
        classes = _context$props.classes,
        label = _context$props.label;
    var optionClick = context.listeners.optionClick;

    var wrapperClasses = 'piq-ui-comp-dropdown ';
    wrapperClasses += classes ? classes : '';

    if (disabled) {
      wrapperClasses += ' dropdown-disabled';
    }

    return h('div', [label && h('div', [h(
      'label',
      { 'class': 'input-label' },
      [label]
    )]), h(
      'div',
      (0, _babelHelperVueJsxMergeProps2.default)([{
        attrs: { tabindex: '0', id: 'dropdown-wrapper' },
        'class': wrapperClasses }, {
        on: {
          'click': function click($event) {
            for (var _len = arguments.length, attrs = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
              attrs[_key - 1] = arguments[_key];
            }

            handleClickOpen.bind(context).apply(undefined, [$event].concat(attrs));
          },
          'blur': function blur($event) {
            for (var _len2 = arguments.length, attrs = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
              attrs[_key2 - 1] = arguments[_key2];
            }

            handleClose.apply(undefined, [$event].concat(attrs));
          }
        }
      }]),
      [selectedOption && selectedOption.value && selectedOption.primaryContent ? h(
        'span',
        { 'class': 'dropdown-value-container' },
        [selectedOption.primaryContent]
      ) : h(
        'span',
        { 'class': 'dropdown-value-container' },
        [placeholder]
      ), h(
        'ul',
        {
          attrs: { id: 'dropdown-container' }
        },
        [renderDropdownOptions(h, context.props, optionClick)]
      )]
    )]);
  }
};

function handleClickOpen(e) {
  // e.preventDefault()
  if (!this.props.disabled && (e.target.id === 'dropdown-wrapper' || e.target.parentElement.id === 'dropdown-wrapper')) {
    var el = e.target.id === 'dropdown-wrapper' ? e.target : e.target.parentElement;

    var classes = el.className;
    if (classes.indexOf('dropdown-open') !== -1) {
      el.className = removeOpenClass(el.className);
    } else {
      el.className += ' dropdown-open';
    }
  }
}

function handleClose(e) {
  setTimeout(function () {
    e.target.className = removeOpenClass(e.target.className);
  }, 150);
}

function closeAfterOptionClick(elem) {
  elem.className = removeOpenClass(elem.className);
}

function onOptionClick(e, option, selectedOption, callback) {
  if (!selectedOption || option.value !== selectedOption.value) {
    // no need to run the whole update chain of events if the same value is re-selected
    callback(option);
  }

  // Some devices detect the click on event on child-elements and the event gets propageted up the tree
  // So this deals with that... not pretty
  if (e.target.nodeName === 'A') {
    closeAfterOptionClick(e.target.parentNode.parentNode.parentNode);
  } else if (e.target.nodeName === 'SPAN') {
    closeAfterOptionClick(e.target.parentNode.parentNode.parentNode.parentNode);
  }
}

function renderDropdownOptions(h, props, optionClick) {
  if (props.options.length === 0 && props.loadingText) {
    return h(
      'li',
      { 'class': 'option' },
      [h(
        'a',
        {
          attrs: { href: '#' }
        },
        [props.loadingText]
      )]
    );
  } else if (props.options.length === 0) {
    return h(
      'li',
      { 'class': 'option' },
      [h(
        'a',
        {
          attrs: { href: '#' }
        },
        ['No options found']
      )]
    );
  } else {
    return props.options.map(function (opt) {
      var classes = 'option';
      classes += props.selectedOption && props.selectedOption.value === opt.value ? ' active' : '';
      return h(
        'li',
        (0, _babelHelperVueJsxMergeProps2.default)([{
          attrs: { value: opt.primaryContent, id: 'dropdown-item' },
          'class': classes }, {
          on: {
            'click': function click($event) {
              for (var _len3 = arguments.length, attrs = Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
                attrs[_key3 - 1] = arguments[_key3];
              }

              (function (e) {
                return onOptionClick(e, opt, props.selectedOption, optionClick);
              }).apply(undefined, [$event].concat(attrs));
            }
          }
        }]),
        [h(
          'a',
          {
            attrs: { href: '#' }
          },
          [h('span', [opt.primaryContent]), opt.secondaryContent ? h('div', [h(
            'span',
            { 'class': 'secondary-content' },
            [opt.secondaryContent]
          )]) : null, h('div', { 'class': 'clear-fix' })]
        )]
      );
    });
  }
}

// Out of the classes, remove dropdown-open and keep the rest
function removeOpenClass(classString) {
  var splitted = classString.split(' ');
  splitted.forEach(function (className, i) {
    if (className === 'dropdown-open') {
      splitted.splice(i, 1);
    }
  });
  return splitted.join(' ');
}